@@ -1,14 +1,12 @@
 ###############################################################################
 #
-# This file copyright (c) 2006 by Randy J. Ray, all rights reserved
+# This file copyright (c) 2006-2008 by Randy J. Ray, all rights reserved
 #
-# Copying and distribution are permitted under the terms of the Artistic
-# License as distributed with Perl versions 5.005 and later. See
-# http://language.perl.com/misc/Artistic.html
+# See "LICENSE" in the documentation for licensing and redistribution terms.
 #
 ###############################################################################
 #
-#   $Id: Agent.pm 33 2006-10-11 08:45:42Z  $
+#   $Id: Agent.pm 47 2008-04-06 10:12:34Z  $
 #
 #   Description:    This is the base class for all protocol agents. It provides
 #                   the skeletal functionality and management of the LWP::UA
@@ -45,7 +43,7 @@
 
 package WebService::ISBNDB::Agent;
 
-use 5.6.0;
+use 5.006;
 use strict;
 use warnings;
 use vars qw($VERSION @PROTOS %PROTOS);
@@ -915,11 +913,11 @@ L<LWP::UserAgent>, L<URI>
 
 Randy J. Ray E<lt>rjray@blackperl.comE<gt>
 
-=head1 COPYRIGHT
+=head1 LICENSE
 
-This module and the code within are copyright (c) 2006 by Randy J. Ray and
-released under the terms of the Artistic License
-(http://www.opensource.org/licenses/artistic-license.php). This
+This module and the code within are
+released under the terms of the Artistic License 2.0
+(http://www.opensource.org/licenses/artistic-license-2.0.php). This
 code may be redistributed under either the Artistic License or the GNU
 Lesser General Public License (LGPL) version 2.1
 (http://www.opensource.org/licenses/lgpl-license.php).
