@@ -1,14 +1,12 @@
 ###############################################################################
 #
-# This file copyright (c) 2006 by Randy J. Ray, all rights reserved
+# This file copyright (c) 2006-2008 by Randy J. Ray, all rights reserved
 #
-# Copying and distribution are permitted under the terms of the Artistic
-# License as distributed with Perl versions 5.005 and later. See
-# http://language.perl.com/misc/Artistic.html
+# See "LICENSE" in the documentation for licensing and redistribution terms.
 #
 ###############################################################################
 #
-#   $Id: REST.pm 33 2006-10-11 08:45:42Z  $
+#   $Id: REST.pm 49 2008-04-06 10:45:43Z  $
 #
 #   Description:    This is the protocol-implementation class for making
 #                   requests via the REST interface. At present, this is the
@@ -36,7 +34,7 @@
 
 package WebService::ISBNDB::Agent::REST;
 
-use 5.6.0;
+use 5.006;
 use strict;
 use warnings;
 no warnings 'redefine';
@@ -49,7 +47,7 @@ use XML::LibXML;
 
 use WebService::ISBNDB::Iterator;
 
-$VERSION = "0.30";
+$VERSION = "0.31";
 
 BEGIN
 {
@@ -169,8 +167,10 @@ sub request_uri : RESTRICTED
         unless $apiloc;
 
     # Only add the "access_key" argument if it isn't already present. They may
-    # have overridden it.
-    $argscopy->{access_key} = $key unless $argscopy->{access_key};
+    # have overridden it. It will have come from the enclosing object under
+    # the label "api_key".
+    $argscopy->{access_key} = $argscopy->{api_key} || $key;
+    delete $argscopy->{api_key}; # Just in case, so to not confuse their API
     # Build the request parameters list
     my @args = ();
     for $key (sort keys %$argscopy)
@@ -867,11 +867,10 @@ L<LWP::UserAgent>
 
 Randy J. Ray E<lt>rjray@blackperl.comE<gt>
 
-=head1 COPYRIGHT
+=head1 LICENSE
 
-This module and the code within are copyright (c) 2006 by Randy J. Ray and
-released under the terms of the Artistic License
-(http://www.opensource.org/licenses/artistic-license.php). This
+This module and the code within are released under the terms of the Artistic
+License 2.0 (http://www.opensource.org/licenses/artistic-license-2.0.php). This
 code may be redistributed under either the Artistic License or the GNU
 Lesser General Public License (LGPL) version 2.1
 (http://www.opensource.org/licenses/lgpl-license.php).
